@@ -106,19 +106,6 @@ public:
      */
     inline operator SEXP() const { return m_sexp ; }
 
-    /* we don't provide implicit converters because 
-       of Item 5 in More Effective C++ */
-    inline bool                     asBool()            { DEPRECATED_AS("asBool") ; return as<bool>(m_sexp) ; } ;
-    inline double                   asDouble()          { DEPRECATED_AS("asDouble") ; return as<double>(m_sexp) ; } ;
-    inline int                      asInt()             { DEPRECATED_AS("asInt") ; return as<int>(m_sexp) ; } ;
-    inline Rbyte                    asRaw()             { DEPRECATED_AS("asRaw") ; return as<Rbyte>(m_sexp) ; } ;
-    inline std::string              asStdString()       { DEPRECATED_AS("asStdString") ; return as<std::string>(m_sexp) ; } ;
-    inline std::vector<int>         asStdVectorInt()    { DEPRECATED_AS("asStdVectorInt") ; return as< std::vector<int> >(m_sexp) ; } ;
-    inline std::vector<double>      asStdVectorDouble() { DEPRECATED_AS("asStdVectorDouble") ; return as< std::vector<double> >(m_sexp) ; } ;
-    inline std::vector<std::string> asStdVectorString() { DEPRECATED_AS("asStdVectorString") ; return as< std::vector<std::string> >(m_sexp) ; } ;
-    inline std::vector<Rbyte>       asStdVectorRaw()    { DEPRECATED_AS("asStdVectorRaw") ; return as< std::vector<Rbyte> >(m_sexp) ; } ;
-    inline std::vector<bool>        asStdVectorBool()   { DEPRECATED_AS("asStdVectorBool") ; return as< std::vector<bool> >(m_sexp) ; } ;
-
     /* attributes */
 
     /**
@@ -315,9 +302,7 @@ private:
     void preserve(){ if( m_sexp != R_NilValue ) R_PreserveObject(m_sexp) ; } 
     void release() { if( m_sexp != R_NilValue ) R_ReleaseObject(m_sexp) ; } 
     virtual void update() {} ;
-    inline void DEPRECATED_AS( const std::string& method ){ 
-    	Rf_warning( "The %s method is deprecated, and will eventually be removed, please use the as<> template function instead", method.c_str() ) ;
-    }
+    
 };
 
 } // namespace Rcpp
