@@ -42,8 +42,8 @@ inline void logTxtFunction(const char* file, const int line, const char* express
 }
 
 SEXP capabilities(){
-	SEXP cap = PROTECT( Rf_allocVector( LGLSXP, 3) ) ;
-	SEXP names = PROTECT( Rf_allocVector( STRSXP, 3 ) ) ;
+	SEXP cap = PROTECT( Rf_allocVector( LGLSXP, 5) ) ;
+	SEXP names = PROTECT( Rf_allocVector( STRSXP, 5 ) ) ;
 #ifdef HAS_VARIADIC_TEMPLATES
 	LOGICAL(cap)[0] = TRUE ;
 #else
@@ -54,10 +54,26 @@ SEXP capabilities(){
 #else
 	LOGICAL(cap)[1] = FALSE ;
 #endif
+	/* exceptions are allways supported */
 	LOGICAL(cap)[2] = TRUE ;
+
+#ifdef HAS_TR1_UNORDERED_MAP
+	LOGICAL(cap)[3] = TRUE ;
+#else
+	LOGICAL(cap)[3] = FALSE ;
+#endif
+
+#ifdef HAS_TR1_UNORDERED_SET
+	LOGICAL(cap)[4] = TRUE ;
+#else
+	LOGICAL(cap)[4] = FALSE ;
+#endif
+
 	SET_STRING_ELT(names, 0, Rf_mkChar("variadic templates") ) ;
 	SET_STRING_ELT(names, 1, Rf_mkChar("initializer lists") ) ;
 	SET_STRING_ELT(names, 2, Rf_mkChar("exception handling") ) ;
+	SET_STRING_ELT(names, 3, Rf_mkChar("tr1 unordered maps") ) ;
+	SET_STRING_ELT(names, 4, Rf_mkChar("tr1 unordered sets") ) ;
 	Rf_setAttrib( cap, R_NamesSymbol, names ) ;
 	UNPROTECT(2) ;
 	return cap ;
